@@ -19,8 +19,7 @@
 
 #include "pps-outlines.h"
 
-struct _PpsOutlinesPrivate
-{
+struct _PpsOutlinesPrivate {
 	gchar *markup;
 	gchar *label;
 	gboolean expand;
@@ -42,8 +41,9 @@ enum {
 	PROP_LINK,
 };
 
-void pps_outlines_set_markup (PpsOutlines *pps_outlines,
-				      const gchar *markup)
+void
+pps_outlines_set_markup (PpsOutlines *pps_outlines,
+                         const gchar *markup)
 {
 	PpsOutlinesPrivate *priv = GET_PRIVATE (pps_outlines);
 
@@ -52,8 +52,9 @@ void pps_outlines_set_markup (PpsOutlines *pps_outlines,
 	g_object_notify (G_OBJECT (pps_outlines), "markup");
 }
 
-void pps_outlines_set_label (PpsOutlines *pps_outlines,
-					   const gchar *label)
+void
+pps_outlines_set_label (PpsOutlines *pps_outlines,
+                        const gchar *label)
 {
 	PpsOutlinesPrivate *priv = GET_PRIVATE (pps_outlines);
 
@@ -62,35 +63,36 @@ void pps_outlines_set_label (PpsOutlines *pps_outlines,
 	g_object_notify (G_OBJECT (pps_outlines), "label");
 }
 
-static void pps_outlines_set_property (GObject      *object,
-					 guint         prop_id,
-					 const GValue *value,
-					 GParamSpec   *pspec)
+static void
+pps_outlines_set_property (GObject *object,
+                           guint prop_id,
+                           const GValue *value,
+                           GParamSpec *pspec)
 {
 	PpsOutlines *outlines = PPS_OUTLINES (object);
 	PpsOutlinesPrivate *priv = GET_PRIVATE (outlines);
 
 	switch (prop_id) {
-		case PROP_MARKUP:
-			pps_outlines_set_markup (outlines,
-					g_value_get_string (value));
-			break;
-		case PROP_LABEL:
-			pps_outlines_set_label (outlines,
-					g_value_get_string (value));
-			break;
-		case PROP_EXPAND:
-			priv->expand = g_value_get_boolean (value);
-			break;
-		case PROP_CHILDREN:
-			priv->children = g_value_get_object (value);
-			break;
-		case PROP_LINK:
-			priv->link = g_object_ref (g_value_get_object (value));
-			break;
-	        default:
-			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-			break;
+	case PROP_MARKUP:
+		pps_outlines_set_markup (outlines,
+		                         g_value_get_string (value));
+		break;
+	case PROP_LABEL:
+		pps_outlines_set_label (outlines,
+		                        g_value_get_string (value));
+		break;
+	case PROP_EXPAND:
+		priv->expand = g_value_get_boolean (value);
+		break;
+	case PROP_CHILDREN:
+		priv->children = g_value_get_object (value);
+		break;
+	case PROP_LINK:
+		priv->link = g_object_ref (g_value_get_object (value));
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
 	}
 }
 
@@ -119,11 +121,11 @@ pps_outlines_get_link (PpsOutlines *pps_outlines)
 void
 pps_outlines_set_expand (PpsOutlines *pps_outlines, gboolean expand)
 {
-    PpsOutlinesPrivate *priv = GET_PRIVATE (pps_outlines);
-    g_return_if_fail (PPS_IS_OUTLINES (pps_outlines));
+	PpsOutlinesPrivate *priv = GET_PRIVATE (pps_outlines);
+	g_return_if_fail (PPS_IS_OUTLINES (pps_outlines));
 
-    priv->expand = expand;
-    g_object_notify (G_OBJECT (pps_outlines), "expand");
+	priv->expand = expand;
+	g_object_notify (G_OBJECT (pps_outlines), "expand");
 }
 
 /**
@@ -136,10 +138,10 @@ pps_outlines_set_expand (PpsOutlines *pps_outlines, gboolean expand)
 gboolean
 pps_outlines_get_expand (PpsOutlines *pps_outlines)
 {
-    g_return_val_if_fail (PPS_IS_OUTLINES (pps_outlines), FALSE);
+	g_return_val_if_fail (PPS_IS_OUTLINES (pps_outlines), FALSE);
 
-    PpsOutlinesPrivate *priv = GET_PRIVATE (pps_outlines);
-    return priv->expand;
+	PpsOutlinesPrivate *priv = GET_PRIVATE (pps_outlines);
+	return priv->expand;
 }
 
 /**
@@ -168,40 +170,40 @@ pps_outlines_set_children (PpsOutlines *pps_outlines, GListModel *children)
 GListModel *
 pps_outlines_get_children (PpsOutlines *pps_outlines)
 {
-    PpsOutlinesPrivate *priv = GET_PRIVATE (pps_outlines);
-    g_return_val_if_fail (PPS_IS_OUTLINES (pps_outlines), NULL);
+	PpsOutlinesPrivate *priv = GET_PRIVATE (pps_outlines);
+	g_return_val_if_fail (PPS_IS_OUTLINES (pps_outlines), NULL);
 
-    return priv->children;
+	return priv->children;
 }
 
 static void
-pps_outlines_get_property (GObject    *object,
-			   guint       prop_id,
-			   GValue     *value,
-			   GParamSpec *pspec)
+pps_outlines_get_property (GObject *object,
+                           guint prop_id,
+                           GValue *value,
+                           GParamSpec *pspec)
 {
 	PpsOutlines *outlines = PPS_OUTLINES (object);
 	PpsOutlinesPrivate *priv = GET_PRIVATE (outlines);
 
 	switch (prop_id) {
-		case PROP_MARKUP:
-			g_value_set_string (value, priv->markup);
-			break;
-		case PROP_LABEL:
-			g_value_set_string (value, priv->label);
-			break;
-		case PROP_EXPAND:
-			g_value_set_boolean (value, priv->expand);
-			break;
-		case PROP_CHILDREN:
-			g_value_set_object (value, priv->children);
-			break;
-		case PROP_LINK:
-			g_value_set_object (value, priv->link);
-			break;
-	        default:
-			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-			break;
+	case PROP_MARKUP:
+		g_value_set_string (value, priv->markup);
+		break;
+	case PROP_LABEL:
+		g_value_set_string (value, priv->label);
+		break;
+	case PROP_EXPAND:
+		g_value_set_boolean (value, priv->expand);
+		break;
+	case PROP_CHILDREN:
+		g_value_set_object (value, priv->children);
+		break;
+	case PROP_LINK:
+		g_value_set_object (value, priv->link);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
 	}
 }
 
@@ -219,11 +221,13 @@ pps_outlines_dispose (GObject *object)
 	G_OBJECT_CLASS (pps_outlines_parent_class)->dispose (object);
 }
 
-static void pps_outlines_init (PpsOutlines *pps_outlines)
+static void
+pps_outlines_init (PpsOutlines *pps_outlines)
 {
 }
 
-static void pps_outlines_class_init (PpsOutlinesClass *klass)
+static void
+pps_outlines_class_init (PpsOutlinesClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
@@ -232,45 +236,45 @@ static void pps_outlines_class_init (PpsOutlinesClass *klass)
 	object_class->dispose = pps_outlines_dispose;
 
 	g_object_class_install_property (object_class,
-					 PROP_MARKUP,
-					 g_param_spec_string ("markup",
-							      "markup",
-							      "The markup of the outlines",
-							      NULL,
-							      G_PARAM_READWRITE |
-                                                              G_PARAM_STATIC_STRINGS));
+	                                 PROP_MARKUP,
+	                                 g_param_spec_string ("markup",
+	                                                      "markup",
+	                                                      "The markup of the outlines",
+	                                                      NULL,
+	                                                      G_PARAM_READWRITE |
+	                                                          G_PARAM_STATIC_STRINGS));
 
 	g_object_class_install_property (object_class,
-					 PROP_LABEL,
-					 g_param_spec_string ("label",
-							      "Label",
-							      "The label of the outlines",
-							      NULL,
-							      G_PARAM_READWRITE |
-                                                              G_PARAM_STATIC_STRINGS));
+	                                 PROP_LABEL,
+	                                 g_param_spec_string ("label",
+	                                                      "Label",
+	                                                      "The label of the outlines",
+	                                                      NULL,
+	                                                      G_PARAM_READWRITE |
+	                                                          G_PARAM_STATIC_STRINGS));
 
 	g_object_class_install_property (object_class,
-					 PROP_EXPAND,
-					 g_param_spec_boolean ("expand",
-							      "expand",
-							      "Whether the outlines should be expanded",
-							      FALSE,
-							      G_PARAM_READWRITE |
-                                                              G_PARAM_STATIC_STRINGS));
+	                                 PROP_EXPAND,
+	                                 g_param_spec_boolean ("expand",
+	                                                       "expand",
+	                                                       "Whether the outlines should be expanded",
+	                                                       FALSE,
+	                                                       G_PARAM_READWRITE |
+	                                                           G_PARAM_STATIC_STRINGS));
 
 	g_object_class_install_property (object_class,
-					 PROP_CHILDREN,
-					 g_param_spec_object ("children",
-							      "Children",
-							      "The children of the outlines",
-							      G_TYPE_LIST_MODEL,
-							      G_PARAM_READWRITE));
+	                                 PROP_CHILDREN,
+	                                 g_param_spec_object ("children",
+	                                                      "Children",
+	                                                      "The children of the outlines",
+	                                                      G_TYPE_LIST_MODEL,
+	                                                      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
-					 PROP_LINK,
-					 g_param_spec_object ("link",
-							      "Link",
-							      "The link of the outlines",
-							      PPS_TYPE_LINK,
-							      G_PARAM_READWRITE));
+	                                 PROP_LINK,
+	                                 g_param_spec_object ("link",
+	                                                      "Link",
+	                                                      "The link of the outlines",
+	                                                      PPS_TYPE_LINK,
+	                                                      G_PARAM_READWRITE));
 }
