@@ -25,7 +25,7 @@ impl imp::PpsDocumentView {
             .document_action_group
             .lookup_action(name)
             .and_downcast::<gio::SimpleAction>()
-            .unwrap_or_else(|| panic!("there is no action named {}", name));
+            .unwrap_or_else(|| panic!("there is no action named {name}"));
 
         action.set_enabled(enabled);
     }
@@ -67,9 +67,12 @@ impl imp::PpsDocumentView {
             self.set_action_enabled("add-text-annotation", false);
         }
 
-        if let Some(document) = document.dynamic_cast_ref::<DocumentSignatures>() {
-            self.set_action_enabled("digital-signing", document.can_sign());
-        }
+        let can_sign = document
+            .dynamic_cast_ref::<DocumentSignatures>()
+            .map(|doc| doc.can_sign())
+            .unwrap_or_default();
+
+        self.set_action_enabled("digital-signing", can_sign);
 
         self.set_action_enabled("dual-odd-left", dual_mode);
 
@@ -943,7 +946,7 @@ impl imp::PpsDocumentView {
             "purple" => gdk::RGBA::parse("#c061cb").unwrap(),
             "blue" => gdk::RGBA::parse("#3584e4").unwrap(),
             "green" => gdk::RGBA::parse("#33d17a").unwrap(),
-            _ => panic!("unknown color {}", color),
+            _ => panic!("unknown color {color}"),
         }
     }
 
@@ -963,7 +966,7 @@ impl imp::PpsDocumentView {
             "squiggly" => Squiggly,
             "strikethrough" => StrikeOut,
             "underline" => Underline,
-            _ => panic!("unknown style {}", style),
+            _ => panic!("unknown style {style}"),
         }
     }
 
