@@ -108,9 +108,9 @@ impl imp::PpsDocumentView {
         let title = window_title.title();
 
         let new_title = if self.obj().direction() == gtk::TextDirection::Rtl {
-            format!("{} •", title)
+            format!("{title} •")
         } else {
-            format!("• {}", title)
+            format!("• {title}")
         };
 
         window_title.set_title(&new_title);
@@ -183,9 +183,9 @@ impl imp::PpsDocumentView {
         if !display_name.is_empty() {
             if let Some(doc_title) = doc_title.filter(|title| !title.is_empty()) {
                 let title = if ltr {
-                    format!("{} – {}", doc_title, display_name)
+                    format!("{doc_title} – {display_name}")
                 } else {
-                    format!("{} – {}", display_name, doc_title)
+                    format!("{display_name} – {doc_title}")
                 };
 
                 let title = title.replace('\n', " ");
@@ -260,13 +260,13 @@ impl imp::PpsDocumentView {
 
                     if !sigs.is_empty() {
                         if sigs.iter().all(|s| s.is_valid()) {
-                            obj.signature_banner.add_css_class("error");
-                            obj.signature_banner
-                                .set_title(&gettext("Digital Signature is invalid!"));
-                        } else {
                             obj.signature_banner.remove_css_class("error");
                             obj.signature_banner
                                 .set_title(&gettext("Document has been digitally signed."));
+                        } else {
+                            obj.signature_banner.add_css_class("error");
+                            obj.signature_banner
+                                .set_title(&gettext("Digital Signature is invalid!"));
                         }
                         obj.signature_banner.set_revealed(true);
                     }
@@ -519,7 +519,7 @@ impl imp::PpsDocumentView {
             .document()
             .and_dynamic_cast_ref::<DocumentSignatures>()
             .map(|d| d.available_signing_certificates())
-            .unwrap();
+            .unwrap_or_default();
         let dialog = adw::AlertDialog::new(Some(&gettext("Certificate Required")), None);
 
         if !certs.is_empty() {
@@ -661,7 +661,7 @@ impl imp::PpsDocumentView {
         let name = match edit_name.rsplit_once(".") {
             None => edit_name,
             Some((filename, ext)) => {
-                format!("{}-signed.{}", filename, ext)
+                format!("{filename}-signed.{ext}")
             }
         };
 
