@@ -202,7 +202,7 @@ impl imp::PpsDocumentView {
             uri.to_string()
         } else if uri.starts_with("www.") {
             // Not a valid uri, assume https if it starts with www
-            format!("https://{}", uri)
+            format!("https://{uri}")
         } else {
             let path = self
                 .file()
@@ -213,7 +213,7 @@ impl imp::PpsDocumentView {
             glib::filename_to_uri(path, None).unwrap().to_string()
         };
 
-        debug!("Launch external uri: {}", uri);
+        debug!("Launch external uri: {uri}");
 
         glib::spawn_future_local(glib::clone!(
             #[weak(rename_to = obj)]
@@ -260,7 +260,11 @@ impl imp::PpsDocumentView {
         // does, simply ignore it
         let file = self.file().unwrap();
         if file.uri() != uri {
-            application::spawn(Some(&file), action.dest().as_ref(), Some(self.mode.get()));
+            application::spawn(
+                Some(&gio::File::for_uri(&uri)),
+                action.dest().as_ref(),
+                Some(self.mode.get()),
+            );
         }
     }
 
